# Creditas OpenAPI Client

## Start Here

### Disclaimer

This code has been autogenerated by [Swagger Codegen](https://github.com/swagger-api/swagger-codegen). I do only minimal changes, like adding this info, adding helper scripts for code generation, or fixing some bugs (if needed). I'm not affiliated with Banka Creditas.

### Versioning

The package version follows the API version. However, as the autogenerated code or the docs may require fixes, it is necessary to provide an extended versioning (like `1.0.0.1`), where the last number (`1`) represents an additional patch.

Also, surprisingly, **Creditas API versioning does not follow [Semantic Versioning](https://semver.org/)**. E.g. the API version `1.0.1` introduces breaking changes to `1.0.0`. Consider to define the the package version in your requirements like this: `creditas==1.0.0.*`. Then no breaking changes should sneak in, but additional fixes are still allowed.

### License

From [Swagger Codegen license info](https://github.com/swagger-api/swagger-codegen#license-information-on-generated-code):
> When code is generated from this project, it shall be considered AS IS and owned by the user of the software. There are no warranties--expressed or implied--for generated code. You can do what you wish with it, and once generated, the code is your responsibility and subject to the licensing terms that you deem appropriate.

Releasing this code under the MIT license.

## Description

This is specification of the Creditas OpenAPI. It contains definitions of Creditas banking services exposed via API accessible on the internet.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0.1
- Build package: io.swagger.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.creditas.cz/otevrene-bankovnictvi](https://www.creditas.cz/otevrene-bankovnictvi)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install


```sh
pip install creditas
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import creditas 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import creditas
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import creditas
from creditas.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: oauth_code
configuration = creditas.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'
# Configure OAuth2 access token for authorization: oauth_implicit
configuration = creditas.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = creditas.AccountApi(creditas.ApiClient(configuration))
authorization_bearer = 'authorization_bearer_example' # str | Access token (optional)
body = creditas.Body5() # Body5 | Input data structure (optional)

try:
    # Get current account
    api_response = api_instance.d_ps_account_current_get_api(authorization_bearer=authorization_bearer, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AccountApi->d_ps_account_current_get_api: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.creditas.cz/oam/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**d_ps_account_current_get_api**](docs/AccountApi.md#d_ps_account_current_get_api) | **POST** /account/current/get | Get current account
*AccountApi* | [**d_ps_account_list_api**](docs/AccountApi.md#d_ps_account_list_api) | **POST** /account/list | Get account list
*AccountApi* | [**d_ps_account_savings_get_api**](docs/AccountApi.md#d_ps_account_savings_get_api) | **POST** /account/savings/get | Get savings account
*AccountApi* | [**d_ps_account_term_deposit_get_api**](docs/AccountApi.md#d_ps_account_term_deposit_get_api) | **POST** /account/termdeposit/get | Get term deposit account
*AdministrationApi* | [**o_am_client_registration_create_api**](docs/AdministrationApi.md#o_am_client_registration_create_api) | **POST** /client/registration/create | Create client&#39;s application registration
*AispApi* | [**d_ps_aisp_account_balance_get_api**](docs/AispApi.md#d_ps_aisp_account_balance_get_api) | **POST** /aisp/account/balance/get | Get account balance
*AispApi* | [**d_ps_aisp_account_list_api**](docs/AispApi.md#d_ps_aisp_account_list_api) | **POST** /aisp/account/list | Get list of accounts
*AispApi* | [**d_ps_aisp_account_transaction_list_api**](docs/AispApi.md#d_ps_aisp_account_transaction_list_api) | **POST** /aisp/account/transaction/list | Get list of account transactions
*AuthorizationApi* | [**a_ut_authorization_status_get_api**](docs/AuthorizationApi.md#a_ut_authorization_status_get_api) | **POST** /authorization/status/get | Get authorization status
*AuthorizationApi* | [**a_ut_mpin_esign_device_list_api**](docs/AuthorizationApi.md#a_ut_mpin_esign_device_list_api) | **POST** /authorization/mpinesign/device/list | Get device list for MpinEsign
*AuthorizationApi* | [**a_ut_mpin_esign_initiate_api**](docs/AuthorizationApi.md#a_ut_mpin_esign_initiate_api) | **POST** /authorization/mpinesign/initiate | Initiate MpinEsign authorization
*AuthorizationApi* | [**a_ut_redirect_ib_initiate_api**](docs/AuthorizationApi.md#a_ut_redirect_ib_initiate_api) | **POST** /authorization/ib/initiate | Initiate IB authorization
*AuthorizationApi* | [**a_ut_sms_otp_initiate_api**](docs/AuthorizationApi.md#a_ut_sms_otp_initiate_api) | **POST** /authorization/smsotp/initiate | Initiate SMS authorization
*AuthorizationApi* | [**a_ut_sms_otp_perform_api**](docs/AuthorizationApi.md#a_ut_sms_otp_perform_api) | **POST** /authorization/smsotp/perform | Perform SMS authorization
*BalanceApi* | [**d_ps_account_balance_get_api**](docs/BalanceApi.md#d_ps_account_balance_get_api) | **POST** /account/balance/get | Get account balance
*CardApi* | [**c_rd_card_debit_get_api**](docs/CardApi.md#c_rd_card_debit_get_api) | **POST** /card/debit/get | Get debit card
*CardApi* | [**c_rd_card_list_api**](docs/CardApi.md#c_rd_card_list_api) | **POST** /card/list | Get card list
*CispApi* | [**d_ps_cisp_account_balance_check_api**](docs/CispApi.md#d_ps_cisp_account_balance_check_api) | **POST** /cisp/account/balance/check | Check balance for amount
*ExampleApi* | [**s_ys_error_basic_example_get_api**](docs/ExampleApi.md#s_ys_error_basic_example_get_api) | **POST** /example/error/basic | Example of basic error response
*ExampleApi* | [**s_ys_error_transaction_authorization_example_get_api**](docs/ExampleApi.md#s_ys_error_transaction_authorization_example_get_api) | **POST** /example/error/authorization | Example of authorization error response
*ExampleApi* | [**s_ys_error_validation_example_get_api**](docs/ExampleApi.md#s_ys_error_validation_example_get_api) | **POST** /example/error/validation | Example of validation error response
*LoanApi* | [**l_ns_loan_get_api**](docs/LoanApi.md#l_ns_loan_get_api) | **POST** /loan/get | Get loan
*LoanApi* | [**l_ns_loan_list_api**](docs/LoanApi.md#l_ns_loan_list_api) | **POST** /loan/list | Get loan list
*PaymentApi* | [**p_ay_payment_domestic_create_api**](docs/PaymentApi.md#p_ay_payment_domestic_create_api) | **POST** /payment/domestic/create | Create domestic payment order
*PaymentApi* | [**p_ay_payment_foreign_create_api**](docs/PaymentApi.md#p_ay_payment_foreign_create_api) | **POST** /payment/foreign/create | Create foreign payment order
*PaymentApi* | [**p_ay_payment_import_api**](docs/PaymentApi.md#p_ay_payment_import_api) | **POST** /payment/import | Import payment orders(s)
*PaymentApi* | [**p_ay_payment_import_status_get_api**](docs/PaymentApi.md#p_ay_payment_import_status_get_api) | **POST** /payment/import/status/get | Get payment import status
*PaymentApi* | [**p_ay_payment_search_api**](docs/PaymentApi.md#p_ay_payment_search_api) | **POST** /payment/search | Search payment orders
*PaymentApi* | [**p_ay_payment_sepa_create_api**](docs/PaymentApi.md#p_ay_payment_sepa_create_api) | **POST** /payment/sepa/create | Create SEPA payment order
*PaymentApi* | [**p_ay_payment_status_get_api**](docs/PaymentApi.md#p_ay_payment_status_get_api) | **POST** /payment/status/get | Get payment status
*PispApi* | [**d_ps_pisp_account_balance_check_api**](docs/PispApi.md#d_ps_pisp_account_balance_check_api) | **POST** /pisp/account/balance/check | Check balance for amount
*PispApi* | [**p_ay_pisp_payment_domestic_create_api**](docs/PispApi.md#p_ay_pisp_payment_domestic_create_api) | **POST** /pisp/payment/domestic/create | Create domestic payment order
*PispApi* | [**p_ay_pisp_payment_foreign_create_api**](docs/PispApi.md#p_ay_pisp_payment_foreign_create_api) | **POST** /pisp/payment/foreign/create | Create foreign payment order
*PispApi* | [**p_ay_pisp_payment_sepa_create_api**](docs/PispApi.md#p_ay_pisp_payment_sepa_create_api) | **POST** /pisp/payment/sepa/create | Create SEPA payment order
*PispApi* | [**p_ay_pisp_payment_status_get_api**](docs/PispApi.md#p_ay_pisp_payment_status_get_api) | **POST** /pisp/payment/status/get | Get payment status
*StatementApi* | [**s_ta_account_statement_get_api**](docs/StatementApi.md#s_ta_account_statement_get_api) | **POST** /account/statement/get | Download account statement
*StatementApi* | [**s_ta_account_statement_list_api**](docs/StatementApi.md#s_ta_account_statement_list_api) | **POST** /account/statement/list | Get list of available account satements
*TransactionApi* | [**d_ps_account_transaction_export_api**](docs/TransactionApi.md#d_ps_account_transaction_export_api) | **POST** /account/transaction/export | Export account transactions
*TransactionApi* | [**d_ps_account_transaction_search_api**](docs/TransactionApi.md#d_ps_account_transaction_search_api) | **POST** /account/transaction/search | Search account transactions


## Documentation For Models

 - [AccountCurrent](docs/AccountCurrent.md)
 - [AccountSavings](docs/AccountSavings.md)
 - [AccountStatement](docs/AccountStatement.md)
 - [AccountTermDeposit](docs/AccountTermDeposit.md)
 - [AccountTransaction](docs/AccountTransaction.md)
 - [AccountTransactionFilter](docs/AccountTransactionFilter.md)
 - [AccountTransactionFilterPartnerAccount](docs/AccountTransactionFilterPartnerAccount.md)
 - [AccountTransactionPartnerAccount](docs/AccountTransactionPartnerAccount.md)
 - [AispAccount](docs/AispAccount.md)
 - [AispAccountTransaction](docs/AispAccountTransaction.md)
 - [AispAccountTransactionPartnerAccount](docs/AispAccountTransactionPartnerAccount.md)
 - [Body](docs/Body.md)
 - [Body1](docs/Body1.md)
 - [Body10](docs/Body10.md)
 - [Body11](docs/Body11.md)
 - [Body12](docs/Body12.md)
 - [Body13](docs/Body13.md)
 - [Body14](docs/Body14.md)
 - [Body15](docs/Body15.md)
 - [Body16](docs/Body16.md)
 - [Body17](docs/Body17.md)
 - [Body18](docs/Body18.md)
 - [Body19](docs/Body19.md)
 - [Body2](docs/Body2.md)
 - [Body20](docs/Body20.md)
 - [Body21](docs/Body21.md)
 - [Body22](docs/Body22.md)
 - [Body23](docs/Body23.md)
 - [Body24](docs/Body24.md)
 - [Body25](docs/Body25.md)
 - [Body26](docs/Body26.md)
 - [Body27](docs/Body27.md)
 - [Body28](docs/Body28.md)
 - [Body3](docs/Body3.md)
 - [Body4](docs/Body4.md)
 - [Body5](docs/Body5.md)
 - [Body6](docs/Body6.md)
 - [Body7](docs/Body7.md)
 - [Body8](docs/Body8.md)
 - [Body9](docs/Body9.md)
 - [CispaccountbalancecheckCard](docs/CispaccountbalancecheckCard.md)
 - [ClientregistrationcreateClientApplication](docs/ClientregistrationcreateClientApplication.md)
 - [DebitCard](docs/DebitCard.md)
 - [ErrorBasic](docs/ErrorBasic.md)
 - [ErrorTransactionAuthorization](docs/ErrorTransactionAuthorization.md)
 - [ErrorTransactionAuthorizationData](docs/ErrorTransactionAuthorizationData.md)
 - [ErrorValidation](docs/ErrorValidation.md)
 - [ErrorValidationData](docs/ErrorValidationData.md)
 - [ErrorValidationDataParameter](docs/ErrorValidationDataParameter.md)
 - [ErrorValidationDataValidationResult](docs/ErrorValidationDataValidationResult.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse20010](docs/InlineResponse20010.md)
 - [InlineResponse20011](docs/InlineResponse20011.md)
 - [InlineResponse20012](docs/InlineResponse20012.md)
 - [InlineResponse20013](docs/InlineResponse20013.md)
 - [InlineResponse20014](docs/InlineResponse20014.md)
 - [InlineResponse20015](docs/InlineResponse20015.md)
 - [InlineResponse20016](docs/InlineResponse20016.md)
 - [InlineResponse20017](docs/InlineResponse20017.md)
 - [InlineResponse20018](docs/InlineResponse20018.md)
 - [InlineResponse20019](docs/InlineResponse20019.md)
 - [InlineResponse2001Devices](docs/InlineResponse2001Devices.md)
 - [InlineResponse2002](docs/InlineResponse2002.md)
 - [InlineResponse20020](docs/InlineResponse20020.md)
 - [InlineResponse20021](docs/InlineResponse20021.md)
 - [InlineResponse20022](docs/InlineResponse20022.md)
 - [InlineResponse20023](docs/InlineResponse20023.md)
 - [InlineResponse20024](docs/InlineResponse20024.md)
 - [InlineResponse20025](docs/InlineResponse20025.md)
 - [InlineResponse20026](docs/InlineResponse20026.md)
 - [InlineResponse20027](docs/InlineResponse20027.md)
 - [InlineResponse20028](docs/InlineResponse20028.md)
 - [InlineResponse20029](docs/InlineResponse20029.md)
 - [InlineResponse2003](docs/InlineResponse2003.md)
 - [InlineResponse20030](docs/InlineResponse20030.md)
 - [InlineResponse20031](docs/InlineResponse20031.md)
 - [InlineResponse2004](docs/InlineResponse2004.md)
 - [InlineResponse2005](docs/InlineResponse2005.md)
 - [InlineResponse2006](docs/InlineResponse2006.md)
 - [InlineResponse2007](docs/InlineResponse2007.md)
 - [InlineResponse2008](docs/InlineResponse2008.md)
 - [InlineResponse2009](docs/InlineResponse2009.md)
 - [InlineResponse500](docs/InlineResponse500.md)
 - [InlineResponse5001](docs/InlineResponse5001.md)
 - [InlineResponse5002](docs/InlineResponse5002.md)
 - [Loan](docs/Loan.md)
 - [Money](docs/Money.md)
 - [PaymentOrderCommon](docs/PaymentOrderCommon.md)
 - [PaymentOrderCommonPartnerAccount](docs/PaymentOrderCommonPartnerAccount.md)
 - [PaymentOrderDomestic](docs/PaymentOrderDomestic.md)
 - [PaymentOrderDomesticPartnerAccount](docs/PaymentOrderDomesticPartnerAccount.md)
 - [PaymentOrderFilter](docs/PaymentOrderFilter.md)
 - [PaymentOrderFilterPartnerAccount](docs/PaymentOrderFilterPartnerAccount.md)
 - [PaymentOrderForeign](docs/PaymentOrderForeign.md)
 - [PaymentOrderForeignPartnerAccount](docs/PaymentOrderForeignPartnerAccount.md)
 - [PaymentOrderSepa](docs/PaymentOrderSepa.md)
 - [PaymentOrderSepaPartnerAccount](docs/PaymentOrderSepaPartnerAccount.md)
 - [PaymentdomesticcreatePartnerAccount](docs/PaymentdomesticcreatePartnerAccount.md)
 - [PaymentdomesticcreateSourceAccount](docs/PaymentdomesticcreateSourceAccount.md)
 - [PaymentforeigncreatePartnerAccount](docs/PaymentforeigncreatePartnerAccount.md)
 - [PaymentsepacreatePartnerAccount](docs/PaymentsepacreatePartnerAccount.md)
 - [PaymentsepacreateSourceAccount](docs/PaymentsepacreateSourceAccount.md)
 - [PisppaymentdomesticcreateSourceAccount](docs/PisppaymentdomesticcreateSourceAccount.md)
 - [PisppaymentsepacreatePartnerAccount](docs/PisppaymentsepacreatePartnerAccount.md)
 - [SourceAccount](docs/SourceAccount.md)


## Documentation For Authorization


## oauth_code

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://www.creditas.cz/api/oam/authorize
- **Scopes**: 
 - **product_info**: Access product information
 - **balance_info**: Access account balance information
 - **transaction_info**: Access transaction history
 - **payment**: Access payment functionality

## oauth_implicit

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://www.creditas.cz/api/oam/authorize
- **Scopes**: 
 - **product_info**: Access product information
 - **balance_info**: Access account balance information
 - **transaction_info**: Access transaction history
 - **payment**: Access payment functionality


## Author

is@creditas.cz

